@@ -41,6 +41,7 @@
 
 #include <QPainter>
 #include <QTextStream>
+#include <QTimer>
 
 #if BREEZE_HAVE_X11
 #include <QX11Info>
@@ -168,6 +169,11 @@ namespace Breeze
         connect(s.data(), &KDecoration2::DecorationSettings::fontChanged, this, &Decoration::recalculateBorders);
         connect(s.data(), &KDecoration2::DecorationSettings::spacingChanged, this, &Decoration::recalculateBorders);
 
+        // buttons
+        connect(s.data(), &KDecoration2::DecorationSettings::spacingChanged, this, &Decoration::updateButtonsGeometryDelayed);
+        connect(s.data(), &KDecoration2::DecorationSettings::decorationButtonsLeftChanged, this, &Decoration::updateButtonsGeometryDelayed);
+        connect(s.data(), &KDecoration2::DecorationSettings::decorationButtonsRightChanged, this, &Decoration::updateButtonsGeometryDelayed);
+
         // full reconfiguration
         connect(s.data(), &KDecoration2::DecorationSettings::reconfigured, this, &Decoration::reconfigure);
         connect(s.data(), &KDecoration2::DecorationSettings::reconfigured, SettingsProvider::self(), &SettingsProvider::reconfigure, Qt::UniqueConnection );
@@ -359,6 +365,10 @@ namespace Breeze
         updateButtonsGeometry();
     }
 
+    //________________________________________________________________
+    void Decoration::updateButtonsGeometryDelayed()
+    { QTimer::singleShot( 0, this, &Decoration::updateButtonsGeometry ); }
+
     //________________________________________________________________
     void Decoration::updateButtonsGeometry()
     {
@@ -422,6 +432,8 @@ namespace Breeze
 
         }
 
+        update();
+
 
     }
 
