@@ -66,6 +66,7 @@ namespace Breeze
         LineEdit_FrameWidth = 6,
 
         // menu items
+        Menu_FrameWidth = 0,
         MenuItem_MarginWidth = 3,
         MenuItem_ItemSpacing = 4,
         MenuItem_AcceleratorSpace = 16,
@@ -94,7 +95,7 @@ namespace Breeze
         // checkboxes and radio buttons
         CheckBox_Size = 20,
         CheckBox_FocusMarginWidth = 2,
-        CheckBox_ItemSpacing = 6,
+        CheckBox_ItemSpacing = 4,
 
         // menubar items
         MenuBarItem_MarginWidth = 10,
@@ -145,6 +146,7 @@ namespace Breeze
         // toolbox
         ToolBox_TabMinWidth = 80,
         ToolBox_TabItemSpacing = 4,
+        ToolBox_TabMarginWidth = 8,
 
         // tooltips
         ToolTip_FrameWidth = 3,
