@@ -18,7 +18,6 @@
  *************************************************************************/
 
 #include "breezemdiwindowshadow.h"
-#include "breezemdiwindowshadow.moc"
 
 #include "breeze.h"
 #include "breezestyleconfigdata.h"
@@ -36,30 +35,14 @@ namespace Breeze
     {
         if( !_widget ) return;
 
-        const int size( Metrics::Shadow_Size - Metrics::Shadow_Overlap );
-        int topSize( size - Metrics::Shadow_Offset );
-        int bottomSize( size );
-        int rightSize( 0 );
-        int leftSize( 0 );
-
-        switch( StyleConfigData::lightSource() )
-        {
-            case StyleConfigData::LS_TOPLEFT:
-            leftSize = size - Metrics::Shadow_Offset;
-            rightSize = size;
-            break;
-
-            case StyleConfigData::LS_TOPRIGHT:
-            rightSize = size - Metrics::Shadow_Offset;
-            leftSize = size;
-            break;
-
-            case StyleConfigData::LS_TOP:
-            leftSize = size - Metrics::Shadow_Offset/2;
-            rightSize = size - Metrics::Shadow_Offset/2;
-            break;
-
-        }
+        // metrics
+        const int shadowSize = StyleConfigData::shadowSize()*12/16;
+        const int shadowOffset = qMax( shadowSize/2, Metrics::Shadow_Overlap*2 );
+        const int size( shadowSize - Metrics::Shadow_Overlap );
+        const int topSize( size - shadowOffset );
+        const int bottomSize( size );
+        const int leftSize( size - shadowOffset );
+        const int rightSize( size );
 
         // get tileSet rect
         _shadowTilesRect = _widget->frameGeometry().adjusted( -leftSize, -topSize, rightSize, bottomSize );
