@@ -62,6 +62,9 @@ namespace Breeze
         //* reset
         void reset( void );
 
+        //* load config
+        void loadConfig( void );
+
         //* register widget
         bool registerWidget( QWidget*, bool force = false );
 
@@ -82,9 +85,6 @@ namespace Breeze
 
         protected:
 
-        //* true if shadows are supported
-        bool checkSupported( void ) const;
-
         //* true if widget is a menu
         bool isMenu( QWidget* ) const;
 
