@@ -59,7 +59,6 @@ namespace Breeze
     class Helper;
     class MdiWindowShadowFactory;
     class Mnemonics;
-    class PaletteHelper;
     class ShadowHelper;
     class SplitterFactory;
     class WidgetExplorer;
@@ -101,6 +100,9 @@ namespace Breeze
         //* widget unpolishing
         virtual void unpolish( QWidget* );
 
+        //* polish scrollarea
+        void polishScrollArea( QAbstractScrollArea* );
+
         //* pixel metrics
         virtual int pixelMetric(PixelMetric, const QStyleOption* = nullptr, const QWidget* = nullptr) const;
 
@@ -455,6 +457,9 @@ namespace Breeze
         //* return true if passed widget is a menu title (KMenu::addTitle)
         bool isMenuTitle( const QWidget* ) const;
 
+        //* return true if passed widget is a menu title (KMenu::addTitle)
+        bool hasAlteredBackground( const QWidget* ) const;
+
         private:
 
         //*@name scrollbar button types (for addLine and subLine )
@@ -466,9 +471,6 @@ namespace Breeze
         //* helper
         Helper* _helper;
 
-        //* palette helper
-        PaletteHelper* _paletteHelper;
-
         //* shadow helper
         ShadowHelper* _shadowHelper;
 
