@@ -19,11 +19,14 @@
  *************************************************************************/
 
 #include "breezestyleplugin.h"
-#include "breezestyleplugin.moc"
 #include "breezestyle.h"
 
 #include <QApplication>
 
+#if QT_VERSION < 0x050000
+Q_EXPORT_PLUGIN2( breeze-qt, Breeze::StylePlugin )
+#endif
+
 namespace Breeze
 {
 
